@@ -9,7 +9,7 @@ use Error::Pure::Utils qw(err_helper);
 use List::MoreUtils qw(none);
 use Readonly;
 
-our $VERSION = 0.26;
+our $VERSION = 0.27;
 
 # Constants.
 Readonly::Array our @EXPORT_OK => qw(err);
@@ -158,21 +158,22 @@ Install the Error::Pure modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Error-Pure-ANSIColor>
+L<https://github.com/michal-josef-spacek/Error-Pure-ANSIColor>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2013-2017 Michal Špaček
- BSD 2-Clause License
+© 2013-2022 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.26
+0.27
 
 =cut
